/*
 * the Decibel Realtime Communication Framework
 * Copyright (C) 2006 by basyskom GmbH
 *  @author Tobias Hunger <info@basyskom.de>
 * Copyright (C) 2008 George Goldberg <grundleborg@googlemail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

extern "C"
{
#include <signal.h>
}

#include "decibelmain.h"

#include <Decibel/Types>
#include <Decibel/DBusNames>

#include <QtCore/QCoreApplication>
#include <QtCore/QDebug>
#include <QtCore/QTimer>

/**
 * @mainpage The Decibel Realtime Communication Framework Server
 *
 * Welcome to the Decibel Server API reference!
 *
 * Types, functions and classes shared between the Decibel Server implementation
 * and the Decibel Client Library are documented in the
 * <a href="../../common_api/html/index.html">Decibel Common API reference</a>.
 */

namespace
{
    static void signal_handler(int signal)
    {
        if (signal == SIGTERM || signal == SIGINT)
        {
            QCoreApplication * const qapp(QCoreApplication::instance());
            if (0 != qapp) { qapp->quit(); }
            return;
        }
    }
}

int main(int argc, char ** argv)
{
    // Register types as soon as possible...
    Decibel::registerTypes();

    QCoreApplication app(argc, argv);
    app.setOrganizationName(Decibel::organization_name);
    app.setApplicationName(Decibel::system_name);

    // install signal handler:
    if (signal(SIGTERM, signal_handler) == SIG_ERR)
    { qWarning() << QObject::tr("Failed to setup handler for SIGTERM!"); }
    if (signal(SIGINT, signal_handler) == SIG_ERR)
    { qWarning() << QObject::tr("Failed to setup handler for SIGINT!"); }

    /*
     * Create a DecibelMain instance.
     */
    DecibelMain mainApp(&app);
    /*
     * Connect initialization slot to a single shot timer so it starts as soon
     * as the event loop is running.
     */
    QTimer::singleShot(10, &mainApp, SLOT(startSettingUp()));
    /*
     * Start the event loop.
     */
    qDebug() << "Entering main event loop.";
    return app.exec();
}
